/*
     This file is part of GNUnet

     GNUnet is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published
     by the Free Software Foundation; either version 2, or (at your
     option) any later version.

     GNUnet is distributed in the hope that it will be useful, but
     WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
     General Public License for more details.

     You should have received a copy of the GNU General Public License
     along with GNUnet; see the file COPYING.  If not, write to the
     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
     Boston, MA 02111-1307, USA.
*/
/**
 * Common option processing methods for GNUnet clients.
 **/

#include "util/configuration.h"
#include "util/logging.h"
#include "util/returnvalues.h"
#include "applications/common/printhelp.h"

/**
 * Print the default set of client options.
 **/
void printHelpDefault() {
  char * c;

  c = getConfigurationString("FILES",
			     "gnunet.conf");
  printf("-h, --help                    : "\
	 "print this page\n"\
	 "-c FILENAME, --config=FILENAME: "\
	 "load config file (defaults: %s)\n"\
	 "-v, --version                 : "\
	 "print the version number\n"\
	 "-H HOSTNAME, --host=HOSTNAME  : "\
	 "on which host is gnuentd running (default: localhost)\n"\
	 "-L LOGLEVEL, --loglevel=LOGL  : "\
	 "set the loglevel\n"\
	 "-d, --debug                   : "\
	 "run in debug mode, write logs to stderr\n", c);
  xfree(c, "printHelp: config filename");
}

/**
 * Parse the default set of options and set
 * options in the configuration accordingly.
 * This does not include --help or --version.
 * @return YES if the option was a default option
 *  that was successfully processed
 **/
int parseDefaultOptions(char c,
			char * optarg) {
  switch(c) {
  case 'H':
    freeNonNull(setConfigurationString("NETWORK",
				       "HOST",
				       optarg),
		"gnunet-insert option parsing H");
    break;
  case 'c': 
    freeNonNull(setConfigurationString("FILES",
				       "gnunet.conf",
				       optarg),
		"gnunet-insert option parsing c");
    break;
  case 'L':
      freeNonNull(setConfigurationString("GNUNETD",
					 "LOGLEVEL",
					 optarg),
		  "gnunet-insert option parsing L");
      break;
  case 'd':
    freeNonNull(setConfigurationString("GNUNETD",
				       "LOGFILE",
				       NULL),
		"gnunet-insert option parsing d");
    break;
  default:
    return NO;
  }
  return YES;
}
