/*
     This file is part of GNUnet

     GNUnet is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published
     by the Free Software Foundation; either version 2, or (at your
     option) any later version.

     GNUnet is distributed in the hope that it will be useful, but
     WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
     General Public License for more details.

     You should have received a copy of the GNU General Public License
     along with GNUnet; see the file COPYING.  If not, write to the
     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
     Boston, MA 02111-1307, USA.
*/
/**
 * sessionkey management
 * @author Christian Grothoff
 * @file include/server/sessionkey.h
 **/

#ifndef SESSIONKEY_H
#define SESSIONKEY_H

#include "config.h"
#include "util/symcipher.h"
#include "util/returnvalues.h"
#include "util/ports.h"
#include "server/coreapi.h"
#include "server/connection.h"

/**
 * The body of a sessionkey-message.
 **/
typedef struct {
  /**
   * time when this key was created  (network byte order) 
   **/ 
  time_t creationTime; 

  /**
   * the encrypted session key 
   **/ 
  RSAEncryptedData key; 

  /**
   * Signature of the stuff above 
   **/
  Signature signature;

} SKEY_Body;

/**
 * Session key exchange.
 * The header is followed by an inlined SKS.
 **/
typedef struct {
  p2p_HEADER header; 
  SKEY_Body body;
} SKEY_Message;

/**
 * Initialize the sessionkey module.
 **/
void initSessionkey();

/**
 * Shutdown the sessionkey module.
 **/
void doneSessionkey();

/**
 * Accept a session-key that has been sent by another host.
 * The other host must be known (public key)
 * @param hostId the identity of the sender host
 * @param sessionkeySigned the session key that was "negotiated"
 **/
int acceptSessionKey(HostIdentity * sender,
		     TSession * tsession,
		     p2p_HEADER * msg);
 
/**
 * Perform a session key exchange for entry be.
 * First sends a HELO and then the new SKEY
 * (in one unencrypted packet). When called, the 
 * semaphore of at the given index must already be down
 **/
void exchangeKey(BufferEntry * be);

/**
 * Shutdown the connection.
 * Send a HANGUP message to the other side and
 * mark the sessionkey as dead.
 **/
void shutdownConnection(BufferEntry * be);


#endif
/* end of sessionkey.h */
