/*
     This file is part of GNUnet

     GNUnet is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published
     by the Free Software Foundation; either version 2, or (at your
     option) any later version.

     GNUnet is distributed in the hope that it will be useful, but
     WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
     General Public License for more details.

     You should have received a copy of the GNU General Public License
     along with GNUnet; see the file COPYING.  If not, write to the
     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
     Boston, MA 02111-1307, USA.
*/
/**
 * @file include/server/tcpserver.h
 * @author Christian Grothoff
 *
 * TCP server (gnunetd-client communication).
 **/

#ifndef TCPSERVER_H
#define TCPSERVER_H

#include "config.h"
#include "util/configuration.h"
#include "server/handler.h"
#include "server/policy.h"
#include "server/keyservice.h"
#include "server/coreapi.h"
#include "util/semaphore.h"
#include "util/ports.h"



/**
 * Initialize the TCP port and listen for incoming client connections.
 * @return OK on success, SYSERR on error
 **/
int initTCPServer();

/**
 * Shutdown the module.
 * @return OK on success, SYSERR on error
 **/ 
int doneTCPServer();

/**
 * Register a method as a handler for specific message
 * types. 
 * @param type the message type
 * @param callback the method to call if a message of
 *        that type is received, if the callback returns
 *        SYSERR, processing of the message is discontinued
 *        afterwards (all other parts are ignored)
 * @return OK on success, SYSERR if there is already a
 *         handler for that type
 **/
int registerCSHandler(const unsigned short type,
		      CSHandler callback);
  
/**
 * Unregister a method as a handler for specific message
 * types. 
 * @param type the message type
 * @param callback the method to call if a message of
 *        that type is received, if the callback returns
 *        SYSERR, processing of the message is discontinued
 *        afterwards (all other parts are ignored)
 * @return OK on success, SYSERR if there is no or another
 *         handler for that type
 **/
int unregisterCSHandler(const unsigned short type,
			CSHandler callback);

int registerClientExitHandler(ClientExitHandler callback);

int unregisterClientExitHandler(ClientExitHandler callback);


#endif
/* end of tcpserver.h */
