/*
  This file is part of GNUnet.
  (C) 2001, 2002 Christian Grothoff (and other contributing authors)

  GNUnet is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published
  by the Free Software Foundation; either version 2, or (at your
  option) any later version.
  
  GNUnet is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with GNUnet; see the file COPYING.  If not, write to the
  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  Boston, MA 02111-1307, USA.
*/

/**
 * GNUnet statistics module
 * @author Christian Grothoff
 * @file include/util/statistics.h
 **/
#ifndef STATISTICS_H
#define STATISTICS_H

#include "util/tcpio.h"
#include "util/ports.h"
#include "util/cron.h"
#include <stdio.h>

/**
 * Initialize the statistics module.
 **/
void initStatistics();

/**
 * Shutdown the statistics module.
 **/
void doneStatistics();

/**
 * Get a handle to a statistical entity.
 * @param name a description of the entity
 * @return a handle for updating the associated value
 **/
int statHandle(char * name);

/**
 * Manipulate statistics.
 * Sets the core-statistics associated with
 * the handle to value.
 * @param handle the handle for the value to change
 * @param value to what the value should be set
 **/
void statSet(const int handle,
	     const unsigned long long value);

/**
 * Manipulate statistics.
 * Changes the core-statistics associated with
 * the value by delta.
 * @param handle the handle for the value to change
 * @param delta by how much should the value be changed
 **/
void statChange(const int handle,
		const int delta);

/**
 * Send statistics to a TCP socket.
 **/
int sendStatistics(GNUNET_TCP_SOCKET * sock,
		   CS_HEADER * message);


/* ********************* types ************** */

/**
 * Statistics message. Contains the timestamp and an aribtrary
 * (bounded by the maximum CS message size!) number of statistical
 * numbers. If needed, several messages are used.
 **/
typedef struct {
  CS_HEADER header;
  /**
   * For 64-bit alignment...
   **/
  int reserved;
  /* timestamp  (network byte order)*/
  cron_t startTime;
  /* total number of statistical counters */
  int totalCounters;
  /* number of statistical counters in this message */
  int statCounters;
  /* values[statCounters] */
  unsigned long long values[0];
  /* description for each of the values,
     separated by '\0'-terminators; the
     last description is also terminated 
     by a '\0'; again statCounters entries */
  char descriptions[0];
} STATS_CS_MESSAGE;


#endif
